@@ -1410,7 +1410,7 @@ class InfiniteContext:
                 else: file_text = self.getSummaryWEBPage(file_path=file_path, max_tokens=max_tokens)
             else: file_text = self.getSummaryTXT(file_path=file_path, max_tokens=max_tokens)
             tokens_number = self.countTokens(string=file_text)
-            if tokens_number > max_tokens: file_text = self.__getBeginningAndEnd(string=file_text, max_tokens=max_tokens)
+            if tokens_number > max_tokens: file_text = self.getBeginningAndEnd(string=file_text, max_tokens=max_tokens)
             result_text = file_text.strip()
             if len(result_text) < 1: return self.__perpetual_context.getSummaryFile(file_path=file_path, max_tokens=max_tokens, main_page=main_page)
             else: return result_text
